EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'RubyGems_UpdateExtendedData',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates extended properties of a Ruby Gem.'
GO

IF OBJECT_ID('[RubyGems_UpdateExtendedData]') IS NOT NULL DROP PROCEDURE [RubyGems_UpdateExtendedData]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [RubyGems_UpdateExtendedData]
(
	@Feed_Id INT,
	@Gem_Name VARCHAR(100),
	@Project_Url VARCHAR(1000) = NULL,
	@Homepage_Url VARCHAR(1000) = NULL,
	@Wiki_Url VARCHAR(1000) = NULL,
	@Documentation_Url VARCHAR(1000) = NULL,
	@MailingList_Url VARCHAR(1000) = NULL,
	@SourceCode_Url VARCHAR(1000) = NULL,
	@BugTracker_Url VARCHAR(1000) = NULL,
	@Overwrite_Indicator YNINDICATOR = 'Y'
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Overwrite_Indicator = 'Y'

		UPDATE [RubyGems]
		   SET [Project_Url] = COALESCE(@Project_Url, [Project_Url]),
		       [Homepage_Url] = COALESCE(@Homepage_Url, [Homepage_Url]),
			   [Wiki_Url] = COALESCE(@Wiki_Url, [Wiki_Url]),
			   [Documentation_Url] = COALESCE(@Documentation_Url, [Documentation_Url]),
			   [MailingList_Url] = COALESCE(@MailingList_Url, [MailingList_Url]),
			   [SourceCode_Url] = COALESCE(@SourceCode_Url, [SourceCode_Url]),
			   [BugTracker_Url] = COALESCE(@BugTracker_Url, [BugTracker_Url])
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Gem_Name] = @Gem_Name

	ELSE

		UPDATE [RubyGems]
		   SET [Project_Url] = COALESCE([Project_Url], @Project_Url),
		       [Homepage_Url] = COALESCE([Homepage_Url], @Homepage_Url),
			   [Wiki_Url] = COALESCE([Wiki_Url], @Wiki_Url),
			   [Documentation_Url] = COALESCE([Documentation_Url], @Documentation_Url),
			   [MailingList_Url] = COALESCE([MailingList_Url], @MailingList_Url),
			   [SourceCode_Url] = COALESCE([SourceCode_Url], @SourceCode_Url),
			   [BugTracker_Url] = COALESCE([BugTracker_Url], @BugTracker_Url)
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Gem_Name] = @Gem_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [RubyGems_UpdateExtendedData] TO [ProGetUser_Role]
GO